@@ -120,7 +120,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study, decr
             df_day = pd.read_csv(unzip_file_path)
         except pd.errors.EmptyDataError:
             print("pandas.errors.EmptyDataError (location) : " + unzip_file_path)
-            quit()
+            return df_logs_combined
 
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
@@ -170,7 +170,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
                                            "LONG"])[0]
                 location = [lat, long]
             else:
-                location = "NF"
+                location = "OB"
 
         matched_time_list.append(closest_time)
         matched_location_list.append(location)
