@@ -86,14 +86,16 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
     for idx in prompt_feature_df.index:
 
         prompt_hour = prompt_feature_df['Prompt_Hour'][idx]
-        # print(prompt_hour)
+
 
         if prompt_hour > 4:
             prompt_date = prompt_feature_df['Prompt_Date_Datetime'][idx]
         else:
             prompt_date = prompt_feature_df['Prompt_Date_Datetime'][idx] - timedelta(days=1)
 
+        print("prompt date : {}".format(prompt_date))
         df_logs_combined = df_logs_combined[df_logs_combined['Date'] == prompt_date]
+        print(df_logs_combined)
 
         if df_logs_combined.shape[0] == 0:
             waking_hour = np.nan
@@ -126,8 +128,25 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
     else:
         waking_hours_column = np.nan * len(prompt_local_datetime_series)
         sleep_hours_column = np.nan * len(prompt_local_datetime_series)
+        print("^^^ Empty combined log file ^^^")
 
     print("     --- success")
 
 
     return waking_hours_column, sleep_hours_column
+
+if __name__ == "__main__":
+    intermediate_participant_path = r"C:\Users\jixin\Desktop\testing\abc@timestudy_com"
+    date_in_study = "2020-09-24"
+
+    # validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
+    # print(validated_date_list)
+    df_logs_combined = combine_intermediate_file(intermediate_participant_path, date_in_study)
+
+    t = ["Sep 24 08:24:01 2020"]
+    converter = lambda x: datetime.strptime(x, "%b %d %H:%M:%S %Y") if (type(x) != float) else "NF"
+    ta = list(map(converter, t))
+    prompt_date = ta[0].date()
+
+    df_logs_combined = df_logs_combined[df_logs_combined['Date'] == prompt_date]
+    print(df_logs_combined.shape[0])
\ No newline at end of file
